@@ -1,9 +1,9 @@
-from ..utils.api import from_api_json
-from ..utils.checks import check_datetime
-from ..utils.resource import Resource
+from starkcore.utils.api import from_api_json
+from starkcore.utils.resource import Resource
+from starkcore.utils.checks import check_datetime
+from ..utils.parse import parse_and_verify
 from ..pixrequest.log.__log import _resource as _pixrequest_log_resource
 from ..pixreversal.log.__log import _resource as _pixreversal_log_resource
-from ..utils.parse import parse_and_verify
 
 
 _resource_by_subscription = {
@@ -47,7 +47,7 @@ def parse(content, signature, user=None):
     """# Create single notification Event from a content string
     Create a single Event object received from Event listening at subscribed user endpoint.
     If the provided digital signature does not check out with the StarkInfra public key, a
-    starkinfra.exception.InvalidSignatureException will be raised.
+    starkinfra.error.InvalidSignatureError will be raised.
     ## Parameters (required):
     - content [string]: response content from request received at user endpoint (not parsed)
     - signature [string]: base-64 digital signature received at response header "Digital-Signature"
@@ -57,4 +57,10 @@ def parse(content, signature, user=None):
     - Parsed Event object
     """
 
-    return parse_and_verify(content, signature, user, _resource, "event")
+    return parse_and_verify(
+        content=content,
+        signature=signature,
+        user=user,
+        resource=_resource,
+        key="event",
+    )
