@@ -1,7 +1,7 @@
 from ..utils import rest
-from ..utils.checks import check_datetime, check_date
-from ..utils.resource import Resource
 from ..utils.parse import parse_and_verify
+from starkcore.utils.resource import Resource
+from starkcore.utils.checks import check_datetime, check_date
 
 
 class PixRequest(Resource):
@@ -25,7 +25,7 @@ class PixRequest(Resource):
     - receiver_account_type [string]: receiver's bank account type. ex: "checking", "savings", "salary" or "payment"
     - end_to_end_id [string]: central bank's unique transaction ID. ex: "E79457883202101262140HHX553UPqeq"
     ## Parameters (optional):
-    - receiver_key_id [string, default None]: Receiver's dict key. Example: tax_id (CPF/CNPJ).
+    - receiver_key_id [string, default None]: receiver's dict key. ex: "20.018.183/0001-80"
     - description [string, default None]: optional description to override default description to be shown in the bank statement. ex: "Payment for service #1234"
     - reconciliation_id [string, default None]: Reconciliation ID linked to this payment. ex: "b77f5236-7ab9-4487-9f95-66ee6eaf1781"
     - initiator_tax_id [string, default None]: Payment initiator's tax id (CPF/CNPJ). ex: "01234567890" or "20.018.183/0001-80"
@@ -112,8 +112,8 @@ def get(id, user=None):
     return rest.get_id(resource=_resource, id=id, user=user)
 
 
-def query(fields=None, limit=None, after=None, before=None, status=None, tags=None, ids=None, end_to_end_id=None,
-          external_id=None, user=None):
+def query(fields=None, limit=None, after=None, before=None, status=None, tags=None, ids=None, end_to_end_ids=None,
+          external_ids=None, user=None):
     """# Retrieve PixRequests
     Receive a generator of PixRequest objects previously created in the Stark Infra API
     ## Parameters (optional):
@@ -121,7 +121,7 @@ def query(fields=None, limit=None, after=None, before=None, status=None, tags=No
     - limit [integer, default None]: maximum number of objects to be retrieved. Unlimited if None. ex: 35
     - after [datetime.date or string, default None]: date filter for objects created or updated only after specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created or updated only before specified date. ex: datetime.date(2020, 3, 10)
-    - status [string, default None]: filter for status of retrieved objects. ex: "success" or "failed"
+    - status [string, default None]: filter for status of retrieved objects. ex: ["success", "failed"]
     - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
     - end_to_end_ids [list of strings, default None]: central bank's unique transaction IDs. ex: ["E79457883202101262140HHX553UPqeq", "E79457883202101262140HHX553UPxzx"]
@@ -139,14 +139,14 @@ def query(fields=None, limit=None, after=None, before=None, status=None, tags=No
         status=status,
         tags=tags,
         ids=ids,
-        end_to_end_id=end_to_end_id,
-        external_id=external_id,
+        end_to_end_ids=end_to_end_ids,
+        external_ids=external_ids,
         user=user,
     )
 
 
 def page(cursor=None, fields=None, limit=None, after=None, before=None, status=None, tags=None, ids=None,
-         end_to_end_id=None, external_id=None, user=None):
+         end_to_end_ids=None, external_ids=None, user=None):
     """# Retrieve paged PixRequests
     Receive a list of up to 100 PixRequest objects previously created in the Stark Infra API and the cursor to the next page.
     Use this function instead of query if you want to manually page your requests.
@@ -156,7 +156,7 @@ def page(cursor=None, fields=None, limit=None, after=None, before=None, status=N
     - limit [integer, default None]: maximum number of objects to be retrieved. Unlimited if None. ex: 35
     - after [datetime.date or string, default None]: date filter for objects created or updated only after specified date. ex: datetime.date(2020, 3, 10)
     - before [datetime.date or string, default None]: date filter for objects created or updated only before specified date. ex: datetime.date(2020, 3, 10)
-    - status [string, default None]: filter for status of retrieved objects. ex: "success" or "failed"
+    - status [string, default None]: filter for status of retrieved objects. ex: ["success", "failed"]
     - tags [list of strings, default None]: tags to filter retrieved objects. ex: ["tony", "stark"]
     - ids [list of strings, default None]: list of ids to filter retrieved objects. ex: ["5656565656565656", "4545454545454545"]
     - end_to_end_ids [list of strings, default None]: central bank's unique transaction IDs. ex: ["E79457883202101262140HHX553UPqeq", "E79457883202101262140HHX553UPxzx"]
@@ -176,24 +176,24 @@ def page(cursor=None, fields=None, limit=None, after=None, before=None, status=N
         status=status,
         tags=tags,
         ids=ids,
-        end_to_end_id=end_to_end_id,
-        external_id=external_id,
+        end_to_end_ids=end_to_end_ids,
+        external_ids=external_ids,
         user=user,
     )
 
 
 def parse(content, signature, user=None):
-    """# Create single authorized PixReversal object from a content string
-    Create a single PixRequest object from a content string received from a handler listening at a subscribed user endpoint.
+    """# Create single verified PixRequest object from a content string
+    Create a single PixRequest object from a content string received from a handler listening at the request url.
     If the provided digital signature does not check out with the StarkInfra public key, a
-    starkinfra.exception.InvalidSignatureException will be raised.
+    starkinfra.error.InvalidSignatureError will be raised.
     ## Parameters (required):
     - content [string]: response content from request received at user endpoint (not parsed)
     - signature [string]: base-64 digital signature received at response header "Digital-Signature"
     ## Parameters (optional):
     - user [Organization/Project object, default None]: Organization or Project object. Not necessary if starkinfra.user was set before function call
     ## Return:
-    - Parsed PixReversal object
+    - Parsed PixRequest object
     """
 
-    return parse_and_verify(content, signature, user, _resource)
+    return parse_and_verify(content=content, signature=signature, user=user, resource=_resource)
